# Bastion module

The bastion module installs a stateless bastion host in a GCP network for the
purposes of accessing a private kubernetes cluster. The bastion is not exposed
to the internet and can only be accessed by Google Identity-Aware Proxies
(IAP). That is to say, by the magic of `gcloud compute ssh`. Egress traffic is
restricted to a given, private Kubernetes API endpoint.

> Documentation below autogenerated with
> `podman run --rm --volume "$(pwd):/terraform-docs:Z" -u $(id -u) quay.io/terraform-docs/terraform-docs:0.16.0 markdown /terraform-docs`

## Requirements

| Name | Version |
|------|---------|
| <a name="requirement_terraform"></a> [terraform](#requirement\_terraform) | >= 1.1.3, < 1.2.0 |
| <a name="requirement_google"></a> [google](#requirement\_google) | >= 4.11.0, < 4.12.0 |
| <a name="requirement_google-beta"></a> [google-beta](#requirement\_google-beta) | >= 4.11.0, < 4.12.0 |
| <a name="requirement_random"></a> [random](#requirement\_random) | >= 3.1.0, < 3.2.0 |

## Providers

| Name | Version |
|------|---------|
| <a name="provider_google"></a> [google](#provider\_google) | >= 4.11.0, < 4.12.0 |
| <a name="provider_random"></a> [random](#provider\_random) | >= 3.1.0, < 3.2.0 |

## Modules

No modules.

## Resources

| Name | Type |
|------|------|
| [google_compute_firewall.bastion-egress](https://registry.terraform.io/providers/hashicorp/google-beta/latest/docs/resources/compute_firewall) | resource |
| [google_compute_firewall.bastion-ingress](https://registry.terraform.io/providers/hashicorp/google-beta/latest/docs/resources/compute_firewall) | resource |
| [google_compute_instance.bastion](https://registry.terraform.io/providers/hashicorp/google-beta/latest/docs/resources/compute_instance) | resource |
| [google_service_account.bastion](https://registry.terraform.io/providers/hashicorp/google-beta/latest/docs/resources/service_account) | resource |
| [random_id.suffix](https://registry.terraform.io/providers/hashicorp/random/latest/docs/resources/id) | resource |
| [random_shuffle.bastion_az](https://registry.terraform.io/providers/hashicorp/random/latest/docs/resources/shuffle) | resource |
| [google_compute_zones.available](https://registry.terraform.io/providers/hashicorp/google-beta/latest/docs/data-sources/compute_zones) | data source |

## Inputs

| Name | Description | Type | Default | Required |
|------|-------------|------|---------|:--------:|
| <a name="input_kubernetes_api_address"></a> [kubernetes\_api\_address](#input\_kubernetes\_api\_address) | IPv4 address of private kubernetes endpoint | `string` | n/a | yes |
| <a name="input_network"></a> [network](#input\_network) | VPC network to deploy bastion into | `string` | `"default"` | no |
| <a name="input_region"></a> [region](#input\_region) | GCP region | `string` | `"us-west1"` | no |
| <a name="input_subnetwork"></a> [subnetwork](#input\_subnetwork) | VPC subnetwork to deploy bastion into | `string` | `"default"` | no |

## Outputs

| Name | Description |
|------|-------------|
| <a name="output_ip_address"></a> [ip\_address](#output\_ip\_address) | private IP address of bastion |
| <a name="output_ssh-cmd"></a> [ssh-cmd](#output\_ssh-cmd) | Instructions to connect to bastion |
